@@ -93,10 +93,10 @@ def parse(page, domain=''):
         '\n', '').strip() if soup.find('title') else ''
     namepattern = r'\W?'.join([l for l in domain.split('.')[0]])
 
-    result['email'] = ';'.join(re.findall(
-        r'([a-zA-Z0-9._-]+@[a-zA-Z0-9._-]+\.[a-zA-Z0-9_-]+)', vis))
-    result['phone'] = ';'.join(re.findall(
-        r'(\d{3}[-\.\s]??\d{3}[-\.\s]??\d{4}|\(\d{3}\)\s*\d{3}[-\.\s]??\d{4}|\d{3}[-\.\s]??\d{4})', vis))
+    result['email'] = ';'.join(set(re.findall(
+        r'([a-zA-Z0-9._-]+@[a-zA-Z0-9._-]+\.[a-zA-Z0-9_-]+)', vis)))
+    result['phone'] = ';'.join(set(re.findall(
+        r'(\d{3}[-\.\s]??\d{3}[-\.\s]??\d{4}|\(\d{3}\)\s*\d{3}[-\.\s]??\d{4}|\d{3}[-\.\s]??\d{4})', vis)))
 
     if not addresses and result['aboutLink']:
         try:
